@@ -25,7 +25,9 @@ class QuizWidget(DOMWidget):
 
     value = Any([]).tag(sync=True)
     quiz_id = Unicode('').tag(sync=True)
-    def __init__(self, value, quiz_id):
+    type = Unicode('').tag(sync=True)
+    def __init__(self, value, quiz_id, type):
         DOMWidget.__init__(self)
         self.value = value
         self.quiz_id = quiz_id
+        self.type = type
